@@ -3,6 +3,7 @@ from numpy import random
 import copy
 import numpy as np
 import matplotlib.pyplot as plt
+import os
 
 # file_handler = logging.FileHandler(filename='nustar_utils_%s.log' % (strftime("%Y-%m-%dT%H:%M:%S", gmtime())))
 # stdout_handler = logging.StreamHandler(sys.stdout)
@@ -281,6 +282,8 @@ def make_enphase(freq,  min_en=3., max_en=70., en_step=0.5, n_bins=32, orbitfile
                         ff.write(enphase_cmd % ('%s%s_ENPHASE.fits' % (tt, unit),
                                          n_bins, freq, nudot, en_step, min_en, max_en) )
                     else:
+                        if not os.path.isfile(en_step):
+                            raise FileExistsError('File %s does not exist' % en_step)
                         ff.write(enphase_cmd_binfile % ('%s%s_ENPHASE.fits' % (tt, unit),
                                                 n_bins, freq, nudot, en_step))
             else:
@@ -292,6 +295,8 @@ def make_enphase(freq,  min_en=3., max_en=70., en_step=0.5, n_bins=32, orbitfile
                         ff.write(enphase_cmd_orbit % ('%s%s_ENPHASE.fits' % (tt, unit), orbitfile,
                                      n_bins, freq, nudot, en_step, min_en, max_en) )
                     else:
+                        if not os.path.isfile(en_step):
+                            raise FileExistsError('File %s does not exist' % en_step)
                         ff.write(enphase_cmd_orbit_binfile % ('%s%s_ENPHASE.fits' % (tt, unit), orbitfile,
                                                       n_bins, freq, nudot, en_step))
 
@@ -360,7 +365,7 @@ def pad_matrix_with_zeros(x1_min, x1_max, pp1, dpp1, x2_min, x2_max):
             new_dpp1.append(np.zeros(n_bins))
 
     if len(x2_min) != len(new_x1_min):
-        raise RuntimeError('PAdding matrix with zeros gave wrong sizes !!')
+        raise RuntimeError('Padding matrix with zeros gave wrong sizes !!')
 
     return np.array(new_x1_min), np.array(new_x1_max), np.array(new_pp1), np.array(new_dpp1)
 
@@ -370,7 +375,10 @@ def read_one_matrix(kind, unit, background_difference_limit=5):
 
     :param kind: 'E' for Energy-Phase, 'T' for Time-Phase
     :param unit: 'A' or 'B' for FPM unit
-    :param background_difference_limit: (if size differs by more than 5, it will skip background subtraction
+    :param background_difference_limit:
+            =0 does not subtract the background
+            <0 subtracts the background after padding background matrix with zeros
+            >0  if sizes of source and background matrices differs by more than this value, it will skip subtraction
     :return: x_min lower edge of time or energy bins
              x_min upper edge of time or energy bins,
              pp matrix
@@ -408,12 +416,13 @@ def read_one_matrix(kind, unit, background_difference_limit=5):
     dptbA = ff[1].data['ERROR']
     ff.close()
 
-    if background_difference_limit <= 0:
+    if background_difference_limit < 0:
         t_minA, t_maxA, ptA, dptA, t_minAb, t_maxAb, ptbA, dptbA = \
             pad_matrices_with_zeros(t_minA, t_maxA, ptA, dptA, t_minAb, t_maxAb, ptbA, dptbA)
         ptA -= ptbA
         dptA = np.sqrt(dptbA ** 2 + dptA ** 2)
-    else:
+        logger.info('Subtracted the background, possibly padded with zeros')
+    elif background_difference_limit > 0:
         if np.abs(len(t_minA) - len(t_minAb)) < background_difference_limit:
             indA, indAb = get_ind_combine(t_minA, t_minAb)
             t_minA = t_minA[indA]
@@ -425,6 +434,8 @@ def read_one_matrix(kind, unit, background_difference_limit=5):
         else:
             logger.info('We do not subtract the background because the difference in matrix dimension is %d' %
                         np.abs(len(t_minA) - len(t_minAb)))
+    else:
+        logger.info("Not subtracting the background")
 
     return t_minA, t_maxA, ptA, dptA
 
@@ -1100,7 +1111,7 @@ def write_orbit_file_from_gbm_page(url, file_name='orbit.dat',
     :param orbital_parameters the orbital parameters to be extracted from the table
         default: ['axsin', 'Eccentricity', 'periastron',
                  'T<sub>', 'Orbital Period', 'Period Deriv.']
-    :return: None
+    :return: file_name or None
     '''
     import requests
     from bs4 import BeautifulSoup
@@ -1130,6 +1141,9 @@ def write_orbit_file_from_gbm_page(url, file_name='orbit.dat',
             if k.lower() in str(tds[0]).lower():
                 orbit.update({k: rx.findall(str(tds[1]))[0]})
 
+    if orbital_parameters[0] not in orbit:
+        logger.warning('Not able to retrieve the orbital parameters as %s could not be read' % orbital_parameters[0])
+        return None
     # it writes the orbit file
     with open(file_name, 'w') as ff:
         for kk in orbital_parameters:
@@ -1145,6 +1159,7 @@ def write_orbit_file_from_gbm_page(url, file_name='orbit.dat',
                     ff.write('%f\n' % (t_90.mjd - 0.25 * float(orbit['Orbital Period'])))
             else:
                 ff.write(orbit[kk] + '\n')
+    return file_name
 
 def get_cross_correlation(pp, plot=False):
 
